@@ -25,7 +25,7 @@ cr = cairo
 # filterwarnings("ignore")
 
 
-version = "0.6.0"  # Current public morpho version
+version = "0.6.1"  # Current public morpho version
 internalVersion = "2.3.2ip"  # Current internal morpho version
 subversion = ""
 DEBUG_MODE = False
@@ -292,6 +292,38 @@ and is meant to be called as a method:
 my_figure.tween(my_other_figure, 0.5)
 '''
 
+# # Documentation TBD
+# class Tween(object):
+#     def __init__(self, function, *, splitter=None):
+#         if isinstance(function, Tween):
+#             if splitter is None:
+#                 splitter = function.splitter
+#             function = function.function
+
+#         self.function = function
+#         self.splitter = splitter
+
+#     def __call__(self, *args, **kwargs):
+#         return self.function(*args, **kwargs)
+
+#     def copy(self):
+#         new = Tween(self.function, self.splitter)
+#         return new
+
+#     def split(self, t):
+#         if self.splitter is None:
+#             return (self, self)
+#         return self.splitter(self, t)
+
+#     def tweenMethod(self, tween=None):
+#         return tweenMethod(tween, splitter=self.splitter)
+
+#     # Method alias
+#     TweenMethod = tweenMethod
+
+
+
+
 # Tween method decorator.
 # Prepended before any tween method's definition as so:
 # @tweenMethod
@@ -301,7 +333,26 @@ my_figure.tween(my_other_figure, 0.5)
 # is possible. e.g. checks the start and end figures are of the same class.
 # It also automatically enforces the rule
 # that t=0 returns self.copy() and t=1 returns other.copy()
-def tweenMethod(tween):
+#
+# Optionally, a splitter function can be assigned to the tween method
+# which enables the tween method to be split into two submethods at
+# a given t-value. It's a function that takes a t-value as input
+# and returns a tuple of two tween methods. Splitters are used to
+# create a new keyfigure seamlessly between two existing keyfigures.
+def tweenMethod(tween=None, *, splitter=None):
+    # If no tween method to decorate, assume we're trying to
+    # modify the default behavior of tweenMethod(), so return
+    # the modified decorator.
+    if tween is None:
+        def decorator(tween):
+            return tweenMethod(tween, splitter=splitter)
+        return decorator
+
+    # If splitter is unspecified but the given tween function
+    # already has a splitter, use its splitter.
+    if splitter is None and hasattr(tween, "splitter"):
+        splitter = tween.splitter
+
     def wrapper(self, other, t, *args, **kwargs):
         if type(self) is not type(other):
             raise TypeError("Tried to tween figures of different class!")
@@ -316,10 +367,19 @@ def tweenMethod(tween):
             twfig = tween(self, other, t, *args, **kwargs)
             twfig.visible = self.visible  # Inherits visibility of self
             return twfig
+    # wrapper = Tween(wrapper, splitter=splitter)
+    wrapper.splitter = splitter
     return wrapper
 
 TweenMethod = tweenMethod  # Initial letter can optionally be uppercase.
 
+# Returns boolean on whether the given tween method has
+# a splitter defined. It is equivalent to
+# hasattr(tweenMethod, "splitter") and tweenMethod.splitter is not None
+def tweenSplittable(tweenMethod):
+    return (hasattr(tweenMethod, "splitter") and \
+            tweenMethod.splitter is not None)
+
 # Converts complex coordinates into screen pixel coordinates
 # according to the screen dimensions and the shape of the cairo
 # context target surface.
@@ -391,16 +451,27 @@ class SavePoint(object):
 # into actual pixel coordinates. In a nutshell, pushPhysicalCoords() applies
 # a transformation which has the effect of converting physical coords to pixel
 # coords. Therefore it should be the last transformation applied in your chain.
-def pushPhysicalCoords(view, ctx):
+#
+# Setting optional save=False means a SavePoint object will not be created
+# and so you will have to manually save the previous CTM.
+#
+# Setting invert=True transforms the CTM in the opposite way.
+# Useful if needing to conjugate a CTM transformation by the
+# physical coordinate transformation.
+def pushPhysicalCoords(view, ctx, *, save=True, invert=False):
     a,b,c,d = view
 
     surface = ctx.get_target()
     WIDTH = surface.get_width()
     HEIGHT = surface.get_height()
 
-    savept = SavePoint(ctx)
-    ctx.scale(WIDTH/(b-a), HEIGHT/(d-c))
-    ctx.translate(-a, -c)
+    savept = SavePoint(ctx) if save else None
+    if invert:
+        ctx.translate(a, c)
+        ctx.scale((b-a)/WIDTH, (d-c)/HEIGHT)
+    else:
+        ctx.scale(WIDTH/(b-a), HEIGHT/(d-c))
+        ctx.translate(-a, -c)
 
     return savept
 
