@@ -3,6 +3,7 @@ import morpholib as morpho
 import morpholib.anim
 import morpholib.color
 from morpholib.tools.basics import *
+from morpholib.tools.dev import BoundingBoxFigure
 
 import cairo
 cr = cairo
@@ -45,7 +46,7 @@ I2 = np.identity(2)
 #                 Generally only used under the hood.
 # physical = Boolean on whether width and height are in physical units or pixels.
 #            Default: True (physical units)
-class Image(morpho.Figure):
+class Image(BoundingBoxFigure):
     def __init__(self, source=None):
 
         # morpho.Figure.__init__(self)
@@ -314,6 +315,9 @@ class Image(morpho.Figure):
     # plus any optional padding. The sequence of the corners is
     # NW, SW, SE, NE.
     def corners(self, pad=0):
+        # NOTE: This method should actually be removable
+        # since its behavior should be identical to the corners()
+        # method inherited from BoundingBoxFigure.
         a,b,c,d = self.box(pad)
 
         NW = a + d*1j
@@ -323,6 +327,7 @@ class Image(morpho.Figure):
 
         return [NW,SW,SE,NE]
 
+
     # Same as corners(), but the coordinates are relative to wherever
     # the image's physical position is.
     def relcorners(self, pad=0):
@@ -607,9 +612,9 @@ class SpaceImage(Image):
 
     def box(self, pad=0):
         align_x, align_y = self.align
-        a = self.pos[0] - self.scale_x*self.width/2*(align_x + 1)
+        a = self.pos[0].tolist() - self.scale_x*self.width/2*(align_x + 1)
         b = a + self.scale_x*self.width
-        c = self.pos[1] - self.scale_y*self.height/2*(align_y + 1)
+        c = self.pos[1].tolist() - self.scale_y*self.height/2*(align_y + 1)
         d = c + self.scale_y*self.height
 
         return [a-pad, b+pad, c-pad, d+pad]
@@ -784,6 +789,9 @@ def Multi(imageMethod, reverseMethod=None):
     return wrapper
 
 
+selfmethods = ["rescaleAspectRatioWH", "scaleByWidth", "scaleByHeight",
+    "rescaleWidth", "rescaleHeight", "newSource", "link", "unlink"]
+
 # Image class that can support drawing multiple images at once. Useful for having
 # one image morph into another image.
 #
@@ -798,6 +806,7 @@ def Multi(imageMethod, reverseMethod=None):
 #
 # Bottom line: It's just like Image except you can tween between different
 # underlying image files.
+@morpho.MultiFigure._selfReturningMethods(Image, selfmethods)
 class MultiImage(morpho.MultiFigure):
 
     def __init__(self, source=None):
@@ -827,18 +836,6 @@ class MultiImage(morpho.MultiFigure):
                 newfig = fig.images[0].copy()
                 self.figures[n] = newfig
 
-    def all(self):
-        raise NotImplementedError
-        if len(self.figures) == 0:
-            raise IndexError("MultiImage has no component images.")
-
-        tweenableNames = list(self.figures[0]._state)
-        tweenableNames.extend(["width", "height"])
-        figures = self.figures
-
-        return super().all(tweenableNames, figures)
-
-
     # tween = morpho.Figure.tween
 
     ### TWEEN METHODS ###
@@ -848,9 +845,13 @@ class MultiImage(morpho.MultiFigure):
 
     @classmethod
     def tweenPivot(cls, angle=tau/2, *args, **kwargs):
-        return Multi(Image.tweenPivot(angle, *args, **kwargs),
+        pivot = Multi(Image.tweenPivot(angle, *args, **kwargs),
             reverseMethod=Image.tweenPivot(-angle, *args, **kwargs)
             )
+        # Enable splitting for this tween method
+        pivot = morpho.pivotTweenMethod(cls.tweenPivot, angle)(pivot)
+
+        return pivot
 
 # Alternative name
 MultImage = MultiImage
